@@ -49,9 +49,6 @@ from pbr import extra_files
 TRUE_VALUES = ('true', '1', 'yes')
 REQUIREMENTS_FILES = ('requirements.txt', 'tools/pip-requires')
 TEST_REQUIREMENTS_FILES = ('test-requirements.txt', 'tools/test-requires')
-# part of the standard library starting with 2.7
-# adding it to the requirements list screws distro installs
-BROKEN_ON_27 = ('argparse', 'importlib', 'ordereddict')
 
 
 def get_requirements_files():
@@ -153,10 +150,6 @@ def parse_requirements(requirements_files=None):
         elif re.match(r'\s*-f\s+', line):
             line = None
             reason = 'Index Location'
-        elif (project_name and
-                project_name in BROKEN_ON_27 and sys.version_info >= (2, 7)):
-            line = None
-            reason = 'Python 2.6 only dependency'
 
         if line is not None:
             requirements.append(line)
@@ -816,10 +809,11 @@ def _get_version_from_git(pre_version):
             except Exception:
                 sha = _run_git_command(
                     ['log', '-n1', '--pretty=format:%h'], git_dir)
-                return "%s.dev%s.g%s" % (pre_version, _get_revno(git_dir), sha)
+                return "%s.dev%s+g%s" % (pre_version, _get_revno(git_dir), sha)
         else:
             return _run_git_command(
-                ['describe', '--always'], git_dir).replace('-', '.')
+                ['describe', '--always'],
+                git_dir).replace('-', '.').replace('.g', '+g')
     # If we don't know the version, return an empty string so at least
     # the downstream users of the value always have the same type of
     # object to work with.
